<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\FinancialConnections;

class AccountService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of Financial Connections <code>Account</code> objects.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\FinancialConnections\Account>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/financial_connections/accounts', $params, $opts);
	}

	/**
	 * Lists the recorded inferred balances for a Financial Connections
	 * <code>Account</code>.
	 *
	 * @param string $parentId
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\FinancialConnections\AccountInferredBalance>
	 */
	public function allInferredBalances($parentId, $params = null, $opts = null) {
		return $this->requestCollection('get', $this->buildPath('/v1/financial_connections/accounts/%s/inferred_balances', $parentId), $params, $opts);
	}

	/**
	 * Lists all owners for a given <code>Account</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\FinancialConnections\AccountOwner>
	 */
	public function allOwners($id, $params = null, $opts = null) {
		return $this->requestCollection('get', $this->buildPath('/v1/financial_connections/accounts/%s/owners', $id), $params, $opts);
	}

	/**
	 * Disables your access to a Financial Connections <code>Account</code>. You will
	 * no longer be able to access data associated with the account (e.g. balances,
	 * transactions).
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\FinancialConnections\Account
	 */
	public function disconnect($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/financial_connections/accounts/%s/disconnect', $id), $params, $opts);
	}

	/**
	 * Refreshes the data associated with a Financial Connections <code>Account</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\FinancialConnections\Account
	 */
	public function refresh($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/financial_connections/accounts/%s/refresh', $id), $params, $opts);
	}

	/**
	 * Retrieves the details of an Financial Connections <code>Account</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\FinancialConnections\Account
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/financial_connections/accounts/%s', $id), $params, $opts);
	}

	/**
	 * Subscribes to periodic refreshes of data associated with a Financial Connections
	 * <code>Account</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\FinancialConnections\Account
	 */
	public function subscribe($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/financial_connections/accounts/%s/subscribe', $id), $params, $opts);
	}

	/**
	 * Unsubscribes from periodic refreshes of data associated with a Financial
	 * Connections <code>Account</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\FinancialConnections\Account
	 */
	public function unsubscribe($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/financial_connections/accounts/%s/unsubscribe', $id), $params, $opts);
	}
}
