<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class InvoiceItemService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of your invoice items. Invoice items are returned sorted by
	 * creation date, with the most recently created invoice items appearing first.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\InvoiceItem>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/invoiceitems', $params, $opts);
	}

	/**
	 * Creates an item to be added to a draft invoice (up to 250 items per invoice). If
	 * no invoice is specified, the item will be on the next invoice created for the
	 * customer specified.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\InvoiceItem
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/invoiceitems', $params, $opts);
	}

	/**
	 * Deletes an invoice item, removing it from an invoice. Deleting invoice items is
	 * only possible when they’re not attached to invoices, or if it’s attached to a
	 * draft invoice.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\InvoiceItem
	 */
	public function delete($id, $params = null, $opts = null) {
		return $this->request('delete', $this->buildPath('/v1/invoiceitems/%s', $id), $params, $opts);
	}

	/**
	 * Retrieves the invoice item with the given ID.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\InvoiceItem
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/invoiceitems/%s', $id), $params, $opts);
	}

	/**
	 * Updates the amount or description of an invoice item on an upcoming invoice.
	 * Updating an invoice item is only possible before the invoice it’s attached to is
	 * closed.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\InvoiceItem
	 */
	public function update($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/invoiceitems/%s', $id), $params, $opts);
	}
}
